@@ -1,4 +1,4 @@
-# $Id: Content.pm,v 1.16.2.1 2003/03/31 12:57:00 joern Exp $
+# $Id: Content.pm,v 1.16.2.2 2003/04/26 15:43:24 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -60,7 +60,7 @@ sub get_probe_title_cnt_command {
 	
 	my $data_source = $self->project->rip_data_source;
 
-	return "dr_exec tcprobe -i $data_source && DVDRIP_SUCCESS";
+	return "dr_exec tcprobe -H 10 -i $data_source && DVDRIP_SUCCESS";
 }
 
 sub get_titles_by_nr {
